Struct rust_tokenizers::Offset [−][src]
pub struct Offset {
pub begin: OffsetSize,
pub end: OffsetSize,
}Expand description
Offset information (in unicode points) to relate a token back to its original input string
Fields
begin: OffsetSizeend: OffsetSizeImplementations
Create a new offset from a begin and end positions
Wrap the offset into an option