Struct rust_tokenizers::vocab::FNetVocab [−][src]
pub struct FNetVocab {
pub values: HashMap<String, i64>,
pub indices: HashMap<i64, String>,
pub unknown_value: &'static str,
pub special_values: HashMap<String, i64>,
pub special_indices: HashMap<i64, String>,
}Expand description
FNetVocab
Vocabulary for FNet tokenizer. Contains the following special values:
- CLS token
- SEP token
- PAD token
- MASK token
Expects a SentencePiece BPE protobuf file when created from file.
Fields
values: HashMap<String, i64>A mapping of tokens as string to indices (i.e. the encoder base)
indices: HashMap<i64, String>A mapping of token ids to strings (i.e. the decoder base)
unknown_value: &'static strThe string to use for unknown (out of vocabulary) tokens
special_values: HashMap<String, i64>A mapping of special value tokens as strings to IDs (i.e. the encoder base for special values), special values typically include things like BOS/EOS markers, class markers, mask markers and padding markers
special_indices: HashMap<i64, String>A mapping of special value tokens as IDs to strings (i.e. the decoder base for special values)
Implementations
Returns the MASK token for FNet ([MASK])