Struct rust_tokenizers::TokenRef [−][src]
Reference token that references the original text, with a string slice representation
Fields
text: &'a strString representation
offset: OffsetStart and end positions of the token with respect to the original text
reference_offsets: &'a [OffsetSize]Sequence of positions with respect to the original text contained in the token.
For example, if the token offset is start: 4, end: 10, corresponding reference_offsets are [4, 5, 6, 7, 8, 9]
mask: MaskMask indicating the type of the token
Implementations
impl<'a> TokenRef<'a>[src]
pub fn new(text: &'a str, offsets: &'a [OffsetSize]) -> TokenRef<'a>[src]
Creates a new token reference from a text and list of offsets.
Parameters
- text (
&str): text reference - offsets (
&[OffsetSize]): reference positions with respect to the original text
Example
use rust_tokenizers::TokenRef; let _original_text = "Hello, world"; let text = "world"; let offsets = &[7, 8, 9, 10, 11]; let token_ref = TokenRef::new(text, offsets);
pub fn to_owned(self) -> Token[src]
Converts a token reference to an owned form.
Example
use rust_tokenizers::TokenRef; let _original_text = "Hello, world"; let text = "world"; let offsets = &[7, 8, 9, 10, 11]; let token_ref = TokenRef::new(text, offsets); let owned_token = token_ref.to_owned();